/**
 * @file mouse.c
 * ICC Propeller mouse driver.
 */
#include "mouse.h"
#include "MouseArray.h"

static mouse_t gmouse;

/*
 * delay function used after start cog and during screen updates
 * @param per is number of ticks to wait ....
 * Careful, if per is too small, the processor will wait until the next count
 * which can be on the order of minutes.
 */
static void wait(int per)
{
    int time = 0;
    asm("mov        %time, cnt");
    asm("add        %time, %per");
    asm("waitcnt    %time, %per");
}

/*
 * start mouse cog
 * See header file for more details.
 */
int mouse_start(int dpin, int cpin)
{
    int id = 0;
    gmouse.dpin = dpin;
    gmouse.cpin = cpin;
    id = cognewNative(MouseArray, &gmouse);
    wait(10000000); // wait for driver to start
    return id;
}

/*
 * stop mouse cog
 * See header file for more details.
 */
void    mouse_stop(int id)
{
    if(id) {
        asm("cogstop %id");
    }
}

/*
 * check if mouse is present
 * See header file for more details.
 */
mouse_type_en mouse_present(void)
{
    return (mouse_type_en) gmouse.present;
}

/*
 * Get mouse buttons state that can be interpreted with mouse_button_en.
 * See header file for more details.
 */
int mouse_buttons(void)
{
    return gmouse.buttons;
}

/*
 * Get mouse x position.
 * See header file for more details.
 */
int mouse_x(void)
{
    return gmouse.x;
}

/*
 * Get mouse y position.
 * See header file for more details.
 */
int mouse_y(void)
{
    return gmouse.y;
}
